package com.qxgmat.service.inline;

import com.github.pagehelper.Page;
import com.nuliji.tools.AbstractService;
import com.nuliji.tools.Transform;
import com.nuliji.tools.exception.ParameterException;
import com.nuliji.tools.exception.SystemException;
import com.nuliji.tools.mybatis.Example;
import com.qxgmat.data.constants.enums.status.DirectionStatus;
import com.qxgmat.data.dao.QuestionNoMapper;
import com.qxgmat.data.dao.entity.Question;
import com.qxgmat.data.dao.entity.QuestionNo;
import com.qxgmat.data.relation.QuestionNoRelationMapper;
import com.qxgmat.data.relation.entity.QuestionNoRelation;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Arrays;
import java.util.Collection;
import java.util.List;
import java.util.stream.Collectors;

@Service
public class QuestionNoService extends AbstractService {
    private static final Logger logger = LoggerFactory.getLogger(QuestionNoService.class);

    @Resource
    private QuestionNoMapper questionNoMapper;

    @Resource
    private QuestionNoRelationMapper questionNoRelationMapper;

    @Resource
    private QuestionService questionService;

    /**
     * 根据题干搜索相似题目
     * @param page
     * @param size
     * @param stem
     * @return
     */
    public List<QuestionNoRelation> searchStem(int page, int size, String stem){
        Example example = new Example(QuestionNo.class);
        example.and(
                example.createCriteria()
                        .andEqualTo("stem", stem)

        );
        List<QuestionNo> p = page(()->select(questionNoMapper, example), page, size);
        return relation(p);
    }

    /**
     * 根据题目编号搜索相似题目
     * @param page
     * @param size
     * @param no
     * @return
     */
    public List<QuestionNoRelation> searchNo(int page, int size, String no){
        Example example = new Example(QuestionNo.class);
        example.and(
                example.createCriteria()
                        .andLike("no", no)
        );
        example.orderBy("id").asc();
        List<QuestionNo> p = page(()->select(questionNoMapper, example), page, size);
        return relation(p);
    }

    /**
     * 根据题目标号列表获取题目
     * @param nos
     * @param module
     * @return
     */
    public List<QuestionNoRelation> listByNos(String[] nos, String module){
        Example example = new Example(QuestionNo.class);
        example.and(
                example.createCriteria()
                        .andIn("no", Arrays.stream(nos).collect(Collectors.toList()))
        );
        if (module != null)
            example.and(
                    example.createCriteria()
                            .andEqualTo("module", module)
            );
        List<QuestionNo> p = select(questionNoMapper, example);
        return relation(p);
    }

    public List<QuestionNoRelation> listByIds(Number[] ids){
        List<QuestionNo> p = select(questionNoMapper, ids);
        return relation(p);
    }

    public List<QuestionNoRelation> relation(List<QuestionNo> p){
        List<QuestionNoRelation> relationList = Transform.convert(p, QuestionNoRelation.class);

        Collection questionIds = Transform.getIds(p, QuestionNo.class, "questionId");
        List<Question> questions = questionService.select(questionIds);
        Transform.combine(relationList, questions, QuestionNoRelation.class, "questionId", "question", Question.class, "id");
        return relationList;
    }


    public QuestionNoRelation relation(QuestionNo p){
        QuestionNoRelation relation = Transform.convert(p, QuestionNoRelation.class);

        Question question = questionService.get(p.getQuestionId());
        relation.setQuestion(question);
        return relation;
    }

    public QuestionNo add(QuestionNo question){
        int result = insert(questionNoMapper, question);
        question = one(questionNoMapper, question.getId());
        if(question == null){
            throw new SystemException("题目添加失败");
        }
        return question;
    }

    public QuestionNo edit(QuestionNo question){
        QuestionNo in = one(questionNoMapper, question.getId());
        if(in == null){
            throw new ParameterException("题目不存在");
        }
        int result = update(questionNoMapper, question);
        return question;
    }

    public boolean delete(Number id){
        QuestionNo in = one(questionNoMapper, id);
        if(in == null){
            throw new ParameterException("题目不存在");
        }
        int result = delete(questionNoMapper, id);
        return result > 0;
    }

    public QuestionNo get(Number id){
        QuestionNo in = one(questionNoMapper, id);

        if(in == null){
            throw new ParameterException("题目不存在");
        }
        return in;
    }

    public Page<QuestionNo> select(int page, int pageSize){
        return select(questionNoMapper, page, pageSize);
    }

    public List<QuestionNo> select(Collection ids){
        return select(questionNoMapper, ids);
    }

}
