package com.qxgmat.service.inline;

import com.github.pagehelper.Page;
import com.nuliji.tools.AbstractService;
import com.nuliji.tools.Transform;
import com.nuliji.tools.exception.ParameterException;
import com.nuliji.tools.exception.SystemException;
import com.nuliji.tools.mybatis.Example;
import com.qxgmat.data.dao.UserQuestionMapper;
import com.qxgmat.data.dao.UserReportMapper;
import com.qxgmat.data.dao.entity.UserQuestion;
import com.qxgmat.data.dao.entity.UserReport;
import com.qxgmat.data.relation.UserReportRelationMapper;
import com.qxgmat.data.relation.entity.UserHomeworkPreviewRelation;
import com.qxgmat.util.shiro.UserRealm;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;

@Service
public class UserReportService extends AbstractService {
    private static final Logger logger = LoggerFactory.getLogger(UserReportService.class);

    @Resource
    private UserReportMapper userReportMapper;
    @Resource
    private UserReportRelationMapper userReportRelationMapper;

    /**
     * 获取所属组卷的所有报告
     * @param paperIds
     * @return
     */
    public Map<Object, Collection<UserReport>> mapByPaper(Collection paperIds){
        Map<Object, Collection<UserReport>> relationMap = new HashMap<>();
        if(paperIds.size() == 0) return relationMap;
        Example example = new Example(UserReport.class);
        example.and(
                example.createCriteria()
                        .andIn("paperId", paperIds)
        );
        List<UserReport> userClassList = select(userReportMapper, example);
        if(userClassList.size() == 0) return relationMap;
        for(UserReport row: userClassList){
            List<UserReport> l;
            Number paperId = row.getPaperId();
            if(!relationMap.containsKey(paperId)){
                l = new ArrayList<>();
                relationMap.put(paperId, l);
            }else{
                l = (List<UserReport>)relationMap.get(paperId);
            }
            l.add(row);
        }
        return relationMap;
    }

    public UserReport add(UserReport report){
        int result = insert(userReportMapper, report);
        report = one(userReportMapper, report.getId());
        if(report == null){
            throw new SystemException("用户报告添加失败");
        }
        return report;
    }

    public UserReport edit(UserReport report){
        UserReport in = one(userReportMapper, report.getId());
        if(in == null){
            throw new ParameterException("用户报告不存在");
        }
        int result = update(userReportMapper, report);
        return report;
    }

    public boolean delete(Number id){
        UserReport in = one(userReportMapper, id);
        if(in == null){
            throw new ParameterException("用户报告不存在");
        }
        int result = delete(userReportMapper, id);
        return result > 0;
    }

    public UserReport get(Number id){
        UserReport in = one(userReportMapper, id);

        if(in == null){
            throw new ParameterException("用户报告不存在");
        }
        return in;
    }

    public Page<UserReport> select(int page, int pageSize){
        return select(userReportMapper, page, pageSize);
    }

    public List<UserReport> select(Collection ids){
        return select(userReportMapper, ids);
    }

}
